@@ -12,11 +12,6 @@ import pytest
 from ibis.tests.util import assert_equal
 from pytest import param
 
-import ibis_omniscidb
-
-# NOTE: TEMPORARY UNTIL IBIS 2.0 IS RELEASED
-ibis.omniscidb = ibis_omniscidb
-
 
 def test_table(alltypes):
     assert isinstance(alltypes, ir.TableExpr)
@@ -56,13 +51,14 @@ def test_session_id_connection(session_con):
     assert new_connection.list_tables()
 
 
-def test_compile_verify(alltypes):
+def test_compile(alltypes):
     supported_expr = alltypes.double_col.sum()
-    assert supported_expr.verify()
+    assert supported_expr.compile()
 
 
 def test_database_layer(con, alltypes):
-    db = con.database()
+    with pytest.warns(FutureWarning):
+        db = con.database()
     t = db.functional_alltypes
 
     assert_equal(t, alltypes)
@@ -78,18 +74,6 @@ def test_compile_toplevel():
     assert str(result) == expected
 
 
-def test_exists_table_with_database(
-    con, alltypes, test_data_db, temp_table, temp_database
-):
-    tmp_db = test_data_db
-    con.create_table(temp_table, alltypes, database=tmp_db)
-
-    assert con.exists_table(temp_table, database=tmp_db)
-    assert not con.exists_table(temp_table, database=temp_database)
-    # check it does exact match rather than partial
-    assert not con.exists_table(temp_table[:-2], database=tmp_db)
-
-
 def test_union_op(alltypes):
     t1 = alltypes
     t2 = alltypes
@@ -229,11 +213,12 @@ def test_read_csv(con, temp_table, filename, alltypes, df_alltypes):
 
     # prepare csv file inside omnisci docker container
     # if the file exists, then it will be overwritten
-    con._execute(
+    con.raw_sql(
         "COPY (SELECT * FROM functional_alltypes) TO '{}'".format(filename)
     )
 
-    db = con.database()
+    with pytest.warns(FutureWarning):
+        db = con.database()
     table = db.table(temp_table)
     table.read_csv(filename, header=False, quotechar='"', delimiter=",")
     df_read_csv = table.execute()
@@ -337,9 +322,9 @@ def test_load_data(con, temp_table, method, format):
 def test_current_database(con):
     assert 'ibis_testing' == con.current_database
 
-    db = con.database('omnisci')
+    with pytest.warns(FutureWarning):
+        db = con.database('omnisci')
     assert 'omnisci' == db.name
-    assert 'omnisci' == db.client.current_database
 
     assert 'ibis_testing' == con.current_database
     con.db_name = 'nonesuch'
